function wavelet_scales(n, type)

type=lower(type);

switch type
    case 'mexican hat'
        fp=1;
        tmax=5*2^n;
    case 'haar'
        fp=10;
        tmax=1*2^n;
    case 'shannon'
        fp=2;
        tmax=1000*2^n;
    otherwise
        warning('Zly typ falki');
end;

t_length=2*tmax*fp;

if t_length<2^10
    nfft=2^10;
else
    nfft=t_length;
end;

t=linspace(-tmax,tmax,t_length);
wavelets=zeros(n,t_length);

for ord=0:n-1
    switch type
        case 'mexican hat'
            wavelets(ord+1,:)=(1/sqrt(2^ord)) * mexican_hat_wavelet(1, t./(2^ord));
            tit='\psi(t)- rzeczywista falka "Mexican hat"';
        case 'haar'
            wavelets(ord+1,:)=(1/sqrt(2^ord)) * haar_wavelet(t./(2^ord));
            tit='\psi(t)- falka Haara';
        case 'shannon'
            wavelets(ord+1,:)=(1/sqrt(2^ord)) * shannon_wavelet(t./(2^ord));
            tit='\psi(t)- rzeczywista falka Shannona';
        otherwise
            warning('Zly typ falki');
    end;
    leg{ord+1}=['j=', num2str(ord)];
end;

figure
subplot(3,1,1);
plot(t/tmax,wavelets');
xlabel('t/t_{max}');
ylabel('\psi_{j}(t)=1/\surd(2^j) * \psi(t/(2^j)');
title(tit);
legend(leg);
if strcmp(type,'shannon')
    xlim([-50/tmax 50/tmax]);
end;
grid on;

%WGMout=zeros(n,nfft/2);

for ord=0:n-1
    [f, WGMout(ord+1,:)] = WGM(wavelets(ord+1,:), nfft, fp, [], [] ,[]);
end;

subplot(3,1,2);
plot(f/fp,WGMout');
xlabel('f/f_{p}');
ylabel('\Psi_{j}(f)=WGM(\psi_{j}(t))');
title('Widmowa Gsto Mocy');
grid on;


Pout=zeros(n,1);
for ord=0:n-1
    Pout(ord+1) = P_WGM(WGMout(ord+1,:),fp ,nfft , 0, 0.5*fp);
end;

subplot3 = subplot(3,1,3,'Parent',gcf,'XTick',[0:n-1]);

box(subplot3,'on');
hold(subplot3,'all');

stem(0:n-1,Pout,'Parent',subplot3);
% subplot(3,1,3);
% stem(0:n-1,Pout/max(Pout));
xlabel('j');
ylabel('P_{j}=\Sigma(\Psi_{j}(f))*f_{p}/nfft');
title('Moc cakowita');
ylim([0 max(Pout)+0.1*max(Pout)]);
xlim([-0.2 n-1+0.2]);
grid



function psi=mexican_hat_wavelet(sigma, t)

psi=(2/(sqrt(3*sigma)*pi^0.25)) .* (1 - (t.^2)./(sigma.^2)) .* exp( (-t.^2) ./ (2*sigma^2) );


function psi=haar_wavelet(t)

psi=zeros(size(t));
for n=1:length(t)
    if t(n)>0 && t(n)<=0.5
        psi(n)=1;
    elseif t(n)>0.5 && t(n)<=1
        psi(n)=-1;
    end;
end;

function psi=shannon_wavelet(t)

% psi=sinc(t/2) .* cos(3*pi*t/2);
psi=2 * sinc(2*t - 1) - sinc(t - 0.5);